Changelog
=========

0.6.1 - 2015-12-28
------------------
- Supports Django 1.7 through 1.9
- Supports Python 2.7, 3.4, and 3.5

0.6.0 - 2015-04-01
------------------
- Requires pylibmc 1.4.1 or greater
- Supports Django 1.4 through 1.8.
- Supports Python 2.5 through 2.7, and Python 3.3 through 3.4
- In Django 1.6 and higher, when the timeout is omitted, the default
  timeout is used, rather than set to "never expire".
